@@ -200,7 +200,7 @@ class ASTProperty extends AbstractASTArtifact
      * Returns the type of this property. This method will return <b>null</b>
      * for all scalar type, only class properties will have a type.
      *
-     * @return \PDepend\Source\AST\AbstractASTClassOrInterface
+     * @return \PDepend\Source\AST\AbstractASTClassOrInterface|null
      * @since  0.9.5
      */
     public function getClass()
@@ -342,11 +342,9 @@ class ASTProperty extends AbstractASTArtifact
      */
     public function __toString()
     {
-        $default = ($this->isDefault() === true ? ' <default>' : '');
         $static  = '';
 
         if ($this->isStatic() === true) {
-            $default = '';
             $static  = ' static';
         }
 
@@ -358,8 +356,7 @@ class ASTProperty extends AbstractASTArtifact
         }
 
         return sprintf(
-            'Property [%s%s%s %s ]%s',
-            $default,
+            'Property [%s%s %s ]%s',
             $visibility,
             $static,
             $this->getName(),
