@@ -935,7 +935,7 @@ class PHPBuilder implements Builder
      * -------------
      * </code>
      *
-     * @return \PDepend\Source\AST\ASTConditionalExpression
+     * @return \PDepend\Source\AST\ASTPrintExpression
      * @since 2.3
      */
     public function buildAstPrintExpression()
@@ -2098,14 +2098,16 @@ class PHPBuilder implements Builder
     protected function findType(array $instances, $qualifiedName)
     {
         $classOrInterfaceName = $this->extractTypeName($qualifiedName);
-        $namespaceName = $this->extractNamespaceName($qualifiedName);
-
         $caseInsensitiveName = strtolower($classOrInterfaceName);
-
         if (!isset($instances[$caseInsensitiveName])) {
             return null;
         }
 
+        $namespaceName = $this->extractNamespaceName($qualifiedName);
+        if ($namespaceName === null) {
+            return null;
+        }
+
         // Check for exact match and return first matching instance
         if (isset($instances[$caseInsensitiveName][$namespaceName])) {
             return reset($instances[$caseInsensitiveName][$namespaceName]);
@@ -2364,7 +2366,7 @@ class PHPBuilder implements Builder
      *
      * @param string $qualifiedName The qualified PHP 5.3 class identifier.
      *
-     * @return string
+     * @return string|null
      */
     protected function extractNamespaceName($qualifiedName)
     {
