@@ -43,6 +43,7 @@
 namespace PDepend\Source\Language\PHP;
 
 use PDepend\Source\AST\ASTCompilationUnit;
+use PDepend\Source\Tokenizer\FullTokenizer;
 use PDepend\Source\Tokenizer\Token;
 use PDepend\Source\Tokenizer\Tokenizer;
 use PDepend\Source\Tokenizer\Tokens;
@@ -187,7 +188,7 @@ if (!defined('T_COALESCE_EQUAL')) {
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
-class PHPTokenizerInternal implements Tokenizer
+class PHPTokenizerInternal implements FullTokenizer
 {
     /**
      * Mapping between php internal tokens and php depend tokens.
@@ -661,6 +662,30 @@ class PHPTokenizerInternal implements Tokenizer
         if (isset($this->tokens[$this->index])) {
             return $this->tokens[$this->index]->type;
         }
+
+        return self::T_EOF;
+    }
+
+    /**
+     * Returns the token type at the given position relatively to the current position.
+     *
+     * @param integer $shift positive or negative to apply to the current index.
+     * @return integer
+     */
+    public function peekAt($shift)
+    {
+        $this->tokenize();
+
+        if ($this->index < -$shift) {
+            return self::T_BOF;
+        }
+
+        $index = $this->index + $shift;
+
+        if (isset($this->tokens[$index])) {
+            return $this->tokens[$index]->type;
+        }
+
         return self::T_EOF;
     }
 
